@@ -1,19 +1,17 @@
-var script_loaded = {};
-
 function script_load(uri, fn) {
-	// load script once.
-	if (script_loaded[uri] !== undefined)
-		return;
 	var script = document.createElement("script");
 	script.type = "text/javascript";
 	script.src = uri;
 	script.async = true;
+	var loaded = 0;
 	var onload = function() {
-		if (script_loaded[uri] === undefined) {
-			script_loaded[uri] = true;
+		// fire fn() once.
+		if (!loaded) {
+			loaded = 1;
 			fn();
 		}
 	};
+	// for IE <= 8.
 	script.onreadystatechange = function() {
 		switch (this.readyState) {
 		case "complete":
@@ -21,20 +19,19 @@ function script_load(uri, fn) {
 			onload();
 		}
 	}
+	// for the normal world.
 	script.onload = function() {
 		onload();
 	};
 	document.getElementsByTagName("head")[0].appendChild(script);
 }
 
-// load list of uri's, fire fn() when all are loaded.
+// load list of uri's (async, order indetermined), fire fn() when all
+// are loaded.
 function scripts_load(uris, fn) {
-	var checkfn = function() {
-		for (var i = 0; i < uris.length; i++)
-			if (script_loaded[uris[i]] === undefined)
-				return; // not all scripts are loaded.
-		fn();
-	};
-	for (var i = 0; i < uris.length; i++)
-		script_load(uris[i], checkfn);
+	for (var i = 0, loaded = 0; i < uris.length; i++)
+		script_load(uris[i], function() {
+			if (++loaded == uris.length)
+				fn();
+		});
 }
